@@ -368,11 +368,6 @@ IPA_xlsxAnalyzer <- function(spreadsheet) {
       } else {
         massDifferenceIsotopes <- tryCatch(as.numeric(PARAM[x0012, 2]), error = function(e) {1.003354835336}, warning = function(w) {1.003354835336})     # Mass difference for isotopic pairs
         PARAM[x0012, 2] <- massDifferenceIsotopes
-        if (massDifferenceIsotopes <= 1.00336 & massDifferenceIsotopes >= 1.00335) {
-          print("Carbon isotopes are selected for ion pairing!")
-        } else {
-          print(paste0("Mass difference to pair isotopes are = '", massDifferenceIsotopes, " Da'!"))
-        }
       }
       #################### Chromatographic peak detection ########################
       x0013 <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0013'), 2])
